#
# spec file for package hlint
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hlint
# no useful debuginfo for Haskell packages without C sources
Name:           hlint
Version:        1.9.35
Release:        2.6
Summary:        Source code suggestions
License:        BSD-3-Clause
Group:          System/Libraries
Url:            http://hackage.haskell.org/package/%{name}
Source0:        http://hackage.haskell.org/packages/archive/%{name}/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-ansi-terminal-devel
BuildRequires:  ghc-cmdargs-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-cpphs-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-haskell-src-exts-devel
BuildRequires:  ghc-hscolour-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-refact-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-uniplate-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
HLint gives suggestions on how to improve your source code.

%package -n ghc-%{name}
Summary:        Haskell %{name} library
Group:          System/Libraries

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Group:          Development/Libraries/Other
Requires:       ghc-%{name} = %{version}-%{release}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q

%build
%{ghc_lib_build}

%install
%{ghc_lib_install}
install -D --mode=444 data/hlint.1 %{buildroot}%{_mandir}/man1/hlint.1

%post -n ghc-%{name}-devel
%{ghc_pkg_recache}

%postun -n ghc-%{name}-devel
%{ghc_pkg_recache}

%files
%defattr(-,root,root,-)
%doc LICENSE
%{_bindir}/%{name}
%{_datadir}/%{name}-%{version}
%{_mandir}/man1/hlint.1.gz

%files -n ghc-%{name} -f ghc-%{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%defattr(-,root,root,-)

%changelog
* Sat Jun 11 2016 mimi.vx@gmail.com
- update to 1.9.35
  * fix parse error reports
  * update hlint.ghci to work with modern GHC
  * Require extra-1.4.9
* Thu Jun  2 2016 mimi.vx@gmail.com
- update to 1.9.34
  * fix some incorrect line numbers in literate Haskell
  * fix literate Haskell and CPP
  * remove type-incorrect "on" hint
  * warn about join seq
  * suggest <|> instead of mplus in a few cases
* Fri Mar 25 2016 mimi.vx@gmail.com
- updateto 1.9.32
  * require cpphs-1.20.1, has important fixes
  * treat select $ specially, as per esqueleto conventions
  * don't modify qualification on substitutions
  * add void/mapM_/forM_ hints
* Wed Mar  2 2016 mimi.vx@gmail.com
- update to 1.9.31
  * don't suggest removing ~ if the Strict extension is on
* Sun Feb 28 2016 mimi.vx@gmail.com
- update to 1.9.30
  * fix incorrect hints of foldr/foldl on a tuple accumulator
  * add warnings about foldable methods on tuple
  * Put warnings before suggestions in the HTML report
* Thu Feb  4 2016 mimi.vx@gmail.com
- update to 1.9.28
  * spot newtype deriving inside classes
  * avoid recompiling everything twice
  * don't suggest removing bang patterns on let
  * Rename HintStructure to HintPattern
  * add an hlint function to the HLint3 API
  * warn about unused DefaultSignatures extension
  * add -XHaskell2010 and fix -XHaskell98
  * Allow checking even if a function has different arities
  * don't warn on a -> (b -> c), it's sometimes sensible
  * make parse errors severity Error
  * warn on otherwise in a pattern variable
  * eta reduce fun x = f $ x
  * don't ever suggest liftM
  * downgrade built in hints, Error => Warning => Suggestion
  * add a Suggestion level severity
  * make sure you close file handles
  * add hint compare x y == EQ and /=
  * add hint concatMap id ==> concat
  * include refactorings is --json output
* Sun Jan  3 2016 mimi.vx@gmail.com
- update to 1.9.26
  * fix all lint warnings
  * expose argsSettings
* Tue Dec 15 2015 mimi.vx@gmail.com
- update to 1.9.25
  * fix stdin output and --refactor on Windows
  * improve spotting redundant brackets around patterns
  * reenable redundant where hint
  * require haskell-src-exts-1.17
  * allow test_ as a prefix
* Tue Nov  3 2015 mimi.vx@gmail.com
- update to 1.9.22
  * Don't suggest redundant lambda on view patterns
  * Add --no-exit-code flag
  * don't suggest string literals
  * disable 'rec' stealing extensions by default
  * add hints for eta-reduced operators
  * integrate a --refactor flag
  * fix the -fglasgow-exts hint
  * better name for moving brackets to eliminate $
  * Extra hints for <$>
  * Remove a redundant fmap hint
  * add =<< rules in addition to >>=
* Sun May 31 2015 mimi.vx@gmail.com
- update to 1.9.21
  * ignore a BOM if it exists
  * don't find files starting with . when searching directories
  * Suggest concat even if the [] is written ""
* Mon Apr 27 2015 mimi.vx@gmail.com
- version bump to 1.9.20
  * fix the zipWith/repeat hint
  * don't remove RecursiveDo if they use the rec statement
  * Add a suggestion concatMap/map ==> concatMap
  * More GHC 7.10 warnings and build support
* Sun Mar 15 2015 mimi.vx@gmail.com
- version bump to 1.9.17
    + support hscolour-1.21
* Fri Jan 30 2015 mimi.vx@gmail.com
- version bump to 1.9.16
    +make "hlint ." work again
    +avoid warnings with GHC 7.10
    +build with GHC 7.10
    +don't suggest const for values using RecordWildCards
    +remove the encoding bits of the API
    +add an HLint3 prototype API
    +make the --quickcheck tests work on GHC 7.8
    +Add --tempdir flag to the test mode
* Sat Nov 22 2014 mimi.vx@gmail.com
- change mv to install command
- move rpmlintrc to hlint.rpmlintrc
* Fri Nov 21 2014 mimi.vx@gmail.com
-initial commit
